@@ -21,7 +21,7 @@ our @EXPORT_OK = qw(
     shifts      unshifts
 );
 
-our $VERSION = '0.26';
+our $VERSION = '0.30';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -120,7 +120,7 @@ sub flow {
     my $args = [@_];
 
     if (ref $args->[0] ne 'CODE') {
-        carp("Expected a function as first argument");
+        return \&noop;
     }
 
     return sub {
@@ -352,29 +352,29 @@ sub unshifts {
     return unshift @{$array}, $val;
 }
 
-sub drop {
+sub _prepare_args {
     my $args     = [@_];
     my $count    = len($args) > 1 ? $args->[0] : 1;
     my $coll     = len($args) > 1 ? $args->[1] : $args->[0];
     my $coll_len = len($coll);
 
+    return ($coll, $count, $coll_len)
+}
+
+sub drop {
+    my ($coll, $count, $coll_len) = _prepare_args(@_);
+
     return [@$coll[$count .. $coll_len - 1]];
 }
 
 sub drop_right {
-    my $args     = [@_];
-    my $count    = len($args) > 1 ? $args->[0] : 1;
-    my $coll     = len($args) > 1 ? $args->[1] : $args->[0];
-    my $coll_len = len($coll);
+    my ($coll, $count, $coll_len) = _prepare_args(@_);
 
     return [@$coll[0 .. ($coll_len - ($count + 1))]];
 }
 
 sub take {
-    my $args     = [@_];
-    my $count    = len($args) > 1 ? $args->[0] : 1;
-    my $coll     = len($args) > 1 ? $args->[1] : $args->[0];
-    my $coll_len = len($coll);
+    my ($coll, $count, $coll_len) = _prepare_args(@_);
 
     if (!$coll_len) {
         return [];
@@ -388,10 +388,7 @@ sub take {
 }
 
 sub take_right {
-    my $args     = [@_];
-    my $count    = len($args) > 1 ? $args->[0] : 1;
-    my $coll     = len($args) > 1 ? $args->[1] : $args->[0];
-    my $coll_len = len($coll);
+    my ($coll, $count, $coll_len) = _prepare_args(@_);
 
     if (!$coll_len) {
         return [];
@@ -537,8 +534,8 @@ sub chain {
 }
 
 sub eql {
-    my $arg1 = shift;
-    my $arg2 = shift;
+    my $arg1 = shift // '';
+    my $arg2 = shift // '';
 
     if (ref $arg1 ne ref $arg2) {
         return 0;
@@ -668,7 +665,7 @@ If end is not specified, it's set to start with start then set to 0.
 
     range(-1, -4, 0);
 
-    # [-1, -1, -1]
+    # []
 
     range(100, 1, 0)
 
@@ -789,7 +786,7 @@ except it uses references instead of @ lists.
 
     pops($array)
 
-    # 1
+    # 3
 
     my $array = [1,2,3];
 
